{
  (
    ((
      {
        {
          {
            c(
              99,
              1 + 1,
              {
                "within that suff"
              }
            )
          }
        }
    }))
  )
}


(((
  1 + 2) * (3 + 4
)))


function(x, y, z) {}
